Registers and Memories
======================

Registers
---------

.. autoclass:: pyrtl.Register
    :members:
    :show-inheritance:
    :special-members: __init__

Memories
--------

.. autoclass:: pyrtl.MemBlock
    :members:
    :special-members: __init__, __getitem__, __setitem__

ROMs
----

.. autoclass:: pyrtl.RomBlock
    :members:
    :show-inheritance:
    :special-members: __init__, __getitem__
